## OrcaNet: A framework for Deep Learning in KM3NeT <br />

[![alt text][image_1]][hyperlink_1] [![alt text][image_2]][hyperlink_2] 
[![alt text][image_3]][hyperlink_3]

  [hyperlink_1]: https://git.km3net.de/ml/OrcaNet/pipelines
  [image_1]: https://git.km3net.de/ml/OrcaNet/badges/master/build.svg

  [hyperlink_2]: https://ml.pages.km3net.de/OrcaNet
  [image_2]: https://examples.pages.km3net.de/km3badges/docs-latest-brightgreen.svg
  
  [hyperlink_3]: https://ml.pages.km3net.de/OrcaNet/coverage
  [image_3]: https://git.km3net.de/ml/OrcaNet/badges/master/coverage.svg

Find more information about KM3NeT on [www.km3net.org](http://www.km3net.org).

OrcaNet is a deep learning framework based on Keras in order to simplify the 
training process of neural networks for astroparticle physics. It incorporates 
automated logging, plotting and validating during the training as well as 
saving and continuing the training process. Additionally, it features easy 
management of multiple neural network inputs and the use of training data 
which is split over multiple files.

In this sense, it tackles many challenges that are usually found in 
astroparticle physics, like huge datasets.

OrcaNet can be installed easily via pip though it is still in the alpha 
development stage. 